from ...utils import get_user, text_response, User, server_id_2_server_name, server_name_2_server_id
import tsugu_api
from arclet.alconna import Alconna, Option, Subcommand, Args, CommandMeta, Empty, Namespace, namespace, command_manager
import tsugu_api_async


alc = Alconna(
        ["解除绑定"],
        Args["index;?#要解绑的绑定编号", int],
        meta=CommandMeta(
            compact=True,
            description="解除绑定",
            usage="验证解绑 记录编号(数字)",
            example="验证解绑 1 : 解绑第一个记录"
        ),
    )


def handler(message: str, user_id: str, platform: str, channel_id: str):
    def mask_data(game_id: str):
        game_id = str(game_id)
        if len(game_id) < 6:
            return game_id[:3] + '*' * (len(game_id) - 3)
        elif len(game_id) < 3:
            return '*' * len(game_id)
        else:
            game_id = game_id[:3] + '*' * (len(game_id) - 6) + game_id[-3:]
        return game_id

    res = alc.parse(message)

    if res.matched:
        user = get_user(user_id, platform)
        if not res.index:
            bind_record = '\n'.join([f'{i + 1}. {mask_data(x.get("game_id"))} {server_id_2_server_name(x.get("server"))}' for i, x in enumerate(user.game_ids)])
            return text_response('请输入正确的记录(数字)\n例如: 解除绑定 1\n当前的绑定记录如下:\n' + bind_record)

        if len(user.game_ids) < int(res.index):
            return text_response('未找到记录')

        server_mode = user.game_ids[int(res.index) - 1].get("server")

        r = tsugu_api.bind_player_request(platform, user.user_id, server_mode, False)
        if r.get('status') != 'success':
            return text_response(r.get('data'))
        return text_response(f'''正在解除，请将 评论(个性签名) 或者 当前使用的 乐队编队名称改为\n{r.get('data')['verifyCode']}\n稍等片刻等待同步后，发送\n验证解绑 {res.index}\n来完成本次身份验证''')
    return res


async def handler_async(message: str, user_id: str, platform: str, channel_id: str):
    def mask_data(game_id: str):
        game_id = str(game_id)
        if len(game_id) < 6:
            return game_id[:3] + '*' * (len(game_id) - 3)
        elif len(game_id) < 3:
            return '*' * len(game_id)
        else:
            game_id = game_id[:3] + '*' * (len(game_id) - 6) + game_id[-3:]
        return game_id

    res = alc.parse(message)

    if res.matched:
        user = get_user(user_id, platform)
        if not res.index:
            bind_record = '\n'.join([f'{i + 1}. {mask_data(x.get("game_id"))} {server_id_2_server_name(x.get("server"))}' for i, x in enumerate(user.game_ids)])
            return text_response('请输入正确的记录(数字)\n例如: 解除绑定 1\n当前的绑定记录如下:\n' + bind_record)

        if len(user.game_ids) < int(res.index):
            return text_response('未找到记录')

        server_mode = user.game_ids[int(res.index) - 1].get("server")

        r = await tsugu_api_async.bind_player_request(platform, user.user_id, server_mode, False)
        if r.get('status') != 'success':
            return text_response(r.get('data'))
        return text_response(f'''正在解除，请将 评论(个性签名) 或者 当前使用的 乐队编队名称改为\n{r.get('data')['verifyCode']}\n稍等片刻等待同步后，发送\n验证解绑 {res.index}\n来完成本次身份验证''')
    return res


from ...utils import get_user, text_response, User, server_id_2_server_name, server_name_2_server_id, server_exists
import tsugu_api
from arclet.alconna import Alconna, Option, Subcommand, Args, CommandMeta, Empty, Namespace, namespace, command_manager
from tsugu_api_core._typing import _ServerName
import tsugu_api_async


alc = Alconna(
        ["玩家状态"],
        Args["serverName;?", _ServerName.__args__]["serverIndex;?", int],
        meta=CommandMeta(
            compact=True,
            description="查询自己的玩家状态",
            usage='根据关键词或活动ID查询活动信息',
            example='''玩家状态 :返回玩家状态(优先当前服务器下第一条记录)
玩家状态 1 :返回绑定的第一条记录的状态
玩家状态 jp :返回绑定的cn服务器的记录的状态'''
        )
    )


def handler(message: str, user_id: str, platform: str, channel_id: str):
    def _utils_search_player_by_game_id(game_id, additional_text=""):
        player_id = str(game_id.get("game_id"))
        server = int(game_id.get("server"))
        response = tsugu_api.search_player(int(player_id), server)
        return response + text_response(additional_text)

    def _case_default(user: User):
        # 优先当前服务器
        for game_id in user.game_ids:
            if game_id.get("server") == user.server_mode:
                text = f' 已查找默认服务器 {server_id_2_server_name(user.server_mode)} 的记录。'
                return _utils_search_player_by_game_id(game_id, text)
        # 兜底逻辑：使用第一个记录
        if user.game_ids:
            game_id = user.game_ids[0]
            text = f' 已查找第一个记录。'
            return _utils_search_player_by_game_id(game_id, text)
        return text_response('未绑定任何记录，可以使用 绑定玩家 进行绑定')

    def _case_server(user: User, server_name: str):
        server_id = server_name_2_server_id(server_name)
        # 服务器不存在
        if not server_exists(server_id):
            return text_response(f'服务器 {server_name} 不存在。')
        # 查找记录
        for game_id in user.game_ids:
            if game_id.get("server") == server_id:
                # 找到记录
                return _utils_search_player_by_game_id(game_id)
        # 未找到记录
        return text_response(f'未在记录中找到服务器 {server_name} 的记录。')

    def _case_index(user: User, index: int):
        if index > len(user.game_ids) or index < 1:
            return text_response(f'未找到记录 {index}。')
        return _utils_search_player_by_game_id(user.game_ids[index - 1])

    res = alc.parse(message)

    if res.matched:
        user = get_user(user_id, platform)
        if res.serverName:
            return _case_server(user, res.serverName)
        elif res.serverIndex:
            return _case_index(user, res.serverIndex)
        else:
            return _case_default(user)
    return res


async def handler_async(message: str, user_id: str, platform: str, channel_id: str):
    async def _utils_search_player_by_game_id(game_id, additional_text=""):
        player_id = str(game_id.get("game_id"))
        server = int(game_id.get("server"))
        response = await tsugu_api_async.search_player(int(player_id), server)
        return response + text_response(additional_text)

    async def _case_default(user: User):
        # 优先当前服务器
        for game_id in user.game_ids:
            if game_id.get("server") == user.server_mode:
                text = f' 已查找默认服务器 {server_id_2_server_name(user.server_mode)} 的记录。'
                return await _utils_search_player_by_game_id(game_id, text)
        # 兜底逻辑：使用第一个记录
        if user.game_ids:
            game_id = user.game_ids[0]
            text = f' 已查找第一个记录。'
            return await _utils_search_player_by_game_id(game_id, text)
        return text_response('未绑定任何记录，可以使用 绑定玩家 进行绑定')

    async def _case_server(user: User, server_name: str):
        server_id = server_name_2_server_id(server_name)
        # 服务器不存在
        if not server_exists(server_id):
            return text_response(f'服务器 {server_name} 不存在。')
        # 查找记录
        for game_id in user.game_ids:
            if game_id.get("server") == server_id:
                # 找到记录
                return await _utils_search_player_by_game_id(game_id)
        # 未找到记录
        return text_response(f'未在记录中找到服务器 {server_name} 的记录。')

    async def _case_index(user: User, index: int):
        if index > len(user.game_ids) or index < 1:
            return text_response(f'未找到记录 {index}。')
        return await _utils_search_player_by_game_id(user.game_ids[index - 1])

    res = alc.parse(message)

    if res.matched:
        user = get_user(user_id, platform)
        if res.serverName:
            return await _case_server(user, res.serverName)
        elif res.serverIndex:
            return await _case_index(user, res.serverIndex)
        else:
            return await _case_default(user)
    return res





from ...utils import get_user, text_response, User, server_id_2_server_name, server_name_2_server_id
import tsugu_api
from arclet.alconna import Alconna, Option, Subcommand, Args, CommandMeta, Empty, Namespace, namespace, command_manager
import tsugu_api_async


alc = Alconna(
        ["查卡池"],
        Args["gachaId#可以通过查活动、查卡等获取", str],
        meta=CommandMeta(
            compact=True,
            description="查卡池",
            usage='根据卡池ID查询卡池信息',
        )
    )


def handler(message: str, user_id: str, platform: str, channel_id: str):
    res = alc.parse(message)

    if res.matched:
        user = get_user(user_id, platform)
        return tsugu_api.search_gacha(user.default_server, res.gachaId)

    return res


async def handler_async(message: str, user_id: str, platform: str, channel_id: str):
    res = alc.parse(message)

    if res.matched:
        user = get_user(user_id, platform)
        return await tsugu_api_async.search_gacha(user.default_server, res.gachaId)

    return res





from ...utils import text_response, User, server_id_2_server_name, server_name_2_server_id
import tsugu_api
import tsugu_api_async
from arclet.alconna import Alconna, Option, Subcommand, Args, CommandMeta, Empty, Namespace, namespace, command_manager


alc = Alconna(
        ["ycm", "车来", "有车吗"],
        meta=CommandMeta(
            compact=True,
            description="获取车牌",
        )
    )


def handler(message: str, user_id: str, platform: str, channel_id: str):
    res = alc.parse(message)

    if res.matched:
        try:
            data = tsugu_api.query_room_number()
        except Exception as e:
            return text_response('获取房间信息失败，请稍后再试')
        if not data:
            return text_response('myc')

        new_data = []
        for i in data:
            if isinstance(i['number'], str):
                i['number'] = int(i['number'])
            i['source'] = i['source_info']['name']
            i['userId'] = i['user_info']['user_id']
            i['time'] = i['time']
            i['avanter'] = i['user_info']['avatar']
            i['userName'] = i['user_info']['username']
            i['rawMessage'] = i['raw_message']
            new_data.append(i)
        # 过滤掉 number 相同的
        new_data = list({v['number']: v for v in new_data}.values())

        return tsugu_api.room_list(new_data)

    return res


async def handler_async(message: str, user_id: str, platform: str, channel_id: str):
    res = alc.parse(message)

    if res.matched:
        try:
            data = await tsugu_api_async.query_room_number()
        except Exception as e:
            return text_response('获取房间信息失败，请稍后再试')
        if not data:
            return text_response('myc')

        new_data = []
        for i in data:
            if isinstance(i['number'], str):
                i['number'] = int(i['number'])
            i['source'] = i['source_info']['name']
            i['userId'] = i['user_info']['user_id']
            i['time'] = i['time']
            i['avanter'] = i['user_info']['avatar']
            i['userName'] = i['user_info']['username']
            i['rawMessage'] = i['raw_message']
            new_data.append(i)
        # 过滤掉 number 相同的
        new_data = list({v['number']: v for v in new_data}.values())

        return await tsugu_api_async.room_list(new_data)

    return res





from ...utils import get_user, text_response, User, server_id_2_server_name, server_name_2_server_id
import tsugu_api
from arclet.alconna import Alconna, Option, Subcommand, Args, CommandMeta, Empty, Namespace, namespace, command_manager
import tsugu_api_async


alc = Alconna(
        ["验证解绑"],
        Args["index#要解绑的绑定编号", int],
        meta=CommandMeta(
            compact=True,
            description="验证解绑",
            usage="验证解绑 记录编号(数字)",
            example="验证解绑 1 : 解绑第一个记录"
        ),
    )


def handler(message: str, user_id: str, platform: str, channel_id: str):
    res = alc.parse(message)

    if res.matched:
        user = get_user(user_id, platform)
        if len(user.game_ids) < int(res.index):
            return text_response('未找到记录')
        player_id = user.game_ids[int(res.index) - 1].get("game_id")
        server_mode = user.game_ids[int(res.index) - 1].get("server")
        r = tsugu_api.bind_player_verification(platform, user.user_id, server_mode, player_id, False)
        if r.get('status') != 'success':
            return text_response(r.get('data'))
        return text_response('解绑成功！')
    
    return res


async def handler_async(message: str, user_id: str, platform: str, channel_id: str):
    res = alc.parse(message)

    if res.matched:
        user = get_user(user_id, platform)
        if len(user.game_ids) < int(res.index):
            return text_response('未找到记录')
        player_id = user.game_ids[int(res.index) - 1].get("game_id")
        server_mode = user.game_ids[int(res.index) - 1].get("server")
        r = await tsugu_api_async.bind_player_verification(platform, user.user_id, server_mode, player_id, False)
        if r.get('status') != 'success':
            return text_response(r.get('data'))
        return text_response('解绑成功！')

    return res




from ...utils import get_user, text_response, User, server_id_2_server_name, server_name_2_server_id
import tsugu_api
from arclet.alconna import Alconna, Option, Subcommand, Args, CommandMeta, Empty, Namespace, namespace, command_manager
from tsugu_api_core._typing import _ServerName
import tsugu_api_async


alc = Alconna(
        ["验证绑定"],
        Args["playerID#你的玩家ID(数字)", int]["serverName#服务器名(字母缩写)", _ServerName],
        meta=CommandMeta(
            compact=True,
            description="验证绑定",)
    )


def handler(message: str, user_id: str, platform: str, channel_id: str):
    res = alc.parse(message)

    if res.matched:
        user = get_user(user_id, platform)
        server = server_name_2_server_id(res.serverName)
        r = tsugu_api.bind_player_verification(platform, user.user_id, server, res.playerID, True)
        if r.get('status') != 'success':
            return text_response(r.get('data'))
        return text_response(f'绑定成功！现在可以使用 玩家状态 {len(user.game_ids) + 1} 查看绑定的玩家状态')
    return res


async def handler_async(message: str, user_id: str, platform: str, channel_id: str):
    res = alc.parse(message)

    if res.matched:
        user = get_user(user_id, platform)
        server = server_name_2_server_id(res.serverName)
        r = await tsugu_api_async.bind_player_verification(platform, user.user_id, server, res.playerID, True)
        if r.get('status') != 'success':
            return text_response(r.get('data'))
        return text_response(f'绑定成功！现在可以使用 玩家状态 {len(user.game_ids) + 1} 查看绑定的玩家状态')
    return res



